package com.xy.service;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.xy.dto.MsgUserMessageDto;
import com.xy.entity.MsgUserMessage;
import com.xy.mapper.MsgUserMessageMapper;
import com.xy.utils.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;

import static com.xy.utils.PlusBeans.toIPage;
import static com.xy.utils.PlusBeans.toPageBean;


/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author 谭斌
 * @since 2023-02-24
 */
@Service
@AllArgsConstructor
@Api(tags = "用户消息")
public class MsgUserMessageServiceImpl extends ServiceImpl<MsgUserMessageMapper, MsgUserMessage> implements MsgUserMessageService {


    @ApiOperation("我的消息")
    @Override
    public R<PageBean<MsgUserMessageDto.PageVO>> myMsgPage(MsgUserMessageDto.Page page) {
        page.setUserId(AuthorizeUtils.getLoginId(Long.class));
        PageBean pageBean = page.getPage();
        LambdaQueryWrapper<MsgUserMessage> lambdaQueryWrapper = new MybatisPlusQuery().eqWrapper(page, MsgUserMessage.class)
                .ge(MsgUserMessage::getCreateTime, page.getBeginCreateTime())
                .le(MsgUserMessage::getCreateTime, page.getEndCreateTime())
                .build();
        IPage<MsgUserMessage> iPage = page(toIPage(pageBean), lambdaQueryWrapper);
        return R.ok(toPageBean(MsgUserMessageDto.PageVO.class, iPage));
    }

    @ApiOperation("新增我的消息")
    @Override
    public R save(@RequestBody @Validated MsgUserMessageDto.Save save) {
        MsgUserMessage saveInfo = Beans.copy(MsgUserMessage.class, save);
        save(saveInfo);
        return R.ok();
    }

    @ApiOperation("更新")
    @Override
    public R update(@RequestBody @Validated MsgUserMessageDto.Update update) {
        MsgUserMessage updateInfo = Beans.copy(MsgUserMessage.class, update);
        updateById(updateInfo);
        return R.ok();
    }
}
